import unittest
import os

import cobs_index as cobs

mydir = os.path.dirname(os.path.realpath(__file__))
datadir = os.path.realpath(mydir + "/../../tests/data")

cobs.disable_cache()

class MainTest(unittest.TestCase):
    # read a directory containing FastA files
    def test_doc_list(self):
        l1 = cobs.DocumentList(datadir + "/fasta")
        self.assertEqual(l1.size(), 7)

        l2 = cobs.DocumentList()
        l2.add_recursive(datadir + "/fasta")
        self.assertEqual(l2.size(), 7)

    # construct classic index and run queries
    def test_classic_construct_query(self):
        index_file = datadir + "/python_test.cobs_classic"

        # construct classic index
        p = cobs.ClassicIndexParameters()
        p.clobber = True
        cobs.classic_construct(
            input=datadir + "/fasta",
            out_file=index_file,
            index_params=p)
        self.assertTrue(os.path.isfile(index_file))

        # run queries
        s = cobs.Search(index_file)
        r = s.search("AGTCAACGCTAAGGCATTTCCCCCCTGCCTCCTGCCTGCTGCCAAGCCCT")
        #print(r)
        self.assertEqual(len(r), 7)
        self.assertEqual(r[0][0], 20)
        self.assertEqual(r[0][1], "sample1")

    # construct compact index and run queries
    def test_compact_construct_query(self):
        index_file = datadir + "/python_test.cobs_compact"

        # construct compact index
        p = cobs.CompactIndexParameters()
        p.clobber = True
        cobs.compact_construct(
            input=datadir + "/fasta",
            out_file=index_file,
            index_params=p)
        self.assertTrue(os.path.isfile(index_file))

        # run queries
        s = cobs.Search(index_file)
        r = s.search("AGTCAACGCTAAGGCATTTCCCCCCTGCCTCCTGCCTGCTGCCAAGCCCT")
        #print(r)
        self.assertEqual(len(r), 7)
        self.assertEqual(r[0][0], 20)
        self.assertEqual(r[0][1], "sample1")

if __name__ == '__main__':
    unittest.main()



import os
import re
import sys
import platform
import subprocess
import unittest

from setuptools import setup, Extension
from setuptools.command.build_ext import build_ext
from distutils.version import LooseVersion

class CMakeExtension(Extension):
    def __init__(self, name, sourcedir=''):
        Extension.__init__(self, name, sources=[])
        self.sourcedir = os.path.abspath(sourcedir)

class CMakeBuild(build_ext):
    def run(self):
        try:
            out = subprocess.check_output(['cmake', '--version'])
        except OSError:
            raise RuntimeError("CMake must be installed to build the following extensions: " +
                               ", ".join(e.name for e in self.extensions))

        if platform.system() == "Windows":
            cmake_version = LooseVersion(re.search(r'version\s*([\d.]+)', out.decode()).group(1))
            if cmake_version < '3.1.0':
                raise RuntimeError("CMake >= 3.1.0 is required on Windows")

        for ext in self.extensions:
            self.build_extension(ext)

    def build_extension(self, ext):
        extdir = os.path.abspath(os.path.dirname(self.get_ext_fullpath(ext.name)))
        cmake_args = ['-DCMAKE_RUNTIME_OUTPUT_DIRECTORY=' + extdir,
                      '-DCMAKE_LIBRARY_OUTPUT_DIRECTORY=' + extdir,
                      '-DPYTHON_EXECUTABLE=' + sys.executable]

        cfg = 'Debug' if self.debug else 'Release'
        build_args = ['--config', cfg]

        if platform.system() == "Windows":
            cmake_args += ['-DCMAKE_LIBRARY_OUTPUT_DIRECTORY_{}={}'.format(cfg.upper(), extdir)]
            if sys.maxsize > 2**32:
                cmake_args += ['-A', 'x64']
            build_args += ['--', '/m']
        else:
            cmake_args += ['-DCMAKE_BUILD_TYPE=' + cfg]
            build_args += ['--', '-j2']

        env = os.environ.copy()
        env['CXXFLAGS'] = '{} -DVERSION_INFO=\\"{}\\"'.format(
            env.get('CXXFLAGS', ''), self.distribution.get_version())

        if not os.path.exists(self.build_temp):
            os.makedirs(self.build_temp)
        subprocess.check_call(
            ['cmake', ext.sourcedir] + cmake_args,
            cwd=self.build_temp, env=env)
        subprocess.check_call(
            ['cmake', '--build', '.', '--target', 'cobs'] + build_args,
            cwd=self.build_temp)
        subprocess.check_call(
            ['cmake', '--build', '.', '--target', 'cobs_python'] + build_args,
            cwd=self.build_temp)

def test_suite():
    test_loader = unittest.TestLoader()
    test_suite = test_loader.discover('python/tests', pattern='test_*.py')
    return test_suite

with open("README.md", "r") as fh:
    long_description = fh.read()

if __name__ == '__main__':
    setup(
        name='cobs_index',
        version='0.1.1',
        description='Compact Bit-Sliced Signature Index (COBS)',
        long_description=long_description,
        long_description_content_type="text/markdown",
        url="https://panthema.net/cobs",
        author='Timo Bingmann',
        author_email='tbdev@panthema.net',
        ext_modules=[CMakeExtension('cobs_index')],
        cmdclass=dict(build_ext=CMakeBuild),
        zip_safe=False,
        # use MANIFEST.in for extra source files
        include_package_data=True,
        # include cobs wrapper script
        scripts=["python/cobs"],
        # find test suite
        test_suite='setup.test_suite',
        classifiers=[
            "Development Status :: 4 - Beta",
            "Topic :: Scientific/Engineering :: Bio-Informatics",
            "Topic :: Text Processing :: Indexing"
        ],
    )
